@@ -14,11 +14,23 @@ product_fields = {
     "human_name": HumanizedNameField(attribute="name"),
 }
 
+vendor_product_fields = {
+    **product_fields,
+    "vendor_name": fields.String(attribute="vendor.name"),
+    "vendor_human_name": HumanizedNameField(attribute="vendor.name"),
+}
+
 
 class ProductListResource(BaseResource):
     @marshal_with(product_fields)
     def get(self, vendor):
-        return ProductController.list_items({**request.args, "vendor": vendor})
+        return ProductController.list_items(
+            {
+                **request.args,
+                "vendor": vendor,
+                "product_page": request.args.get("page", 1),
+            }
+        )
 
 
 class ProductResource(BaseResource):
@@ -34,3 +46,11 @@ class ProductCveResource(BaseResource):
         return CveController.list_items(
             {**request.args, "vendor": vendor, "product": product}
         )
+
+
+class FlatProductListResource(BaseResource):
+    @marshal_with(vendor_product_fields)
+    def get(self):
+        return ProductController.list_items(
+            {**request.args, "product_page": request.args.get("page", 1)}
+        )
